You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by mt...@apache.org on 2009/04/08 14:45:04 UTC

svn commit: r763221 - /commons/sandbox/runtime/trunk/src/main/native/include/arch/windows/acr_arch.h

Author: mturk
Date: Wed Apr  8 12:45:04 2009
New Revision: 763221

URL: http://svn.apache.org/viewvc?rev=763221&view=rev
Log:
Reference few more system dlls

Modified:
    commons/sandbox/runtime/trunk/src/main/native/include/arch/windows/acr_arch.h

Modified: commons/sandbox/runtime/trunk/src/main/native/include/arch/windows/acr_arch.h
URL: http://svn.apache.org/viewvc/commons/sandbox/runtime/trunk/src/main/native/include/arch/windows/acr_arch.h?rev=763221&r1=763220&r2=763221&view=diff
==============================================================================
--- commons/sandbox/runtime/trunk/src/main/native/include/arch/windows/acr_arch.h (original)
+++ commons/sandbox/runtime/trunk/src/main/native/include/arch/windows/acr_arch.h Wed Apr  8 12:45:04 2009
@@ -48,14 +48,17 @@
     JNIEXPORT RT JNICALL Java_org_apache_commons_runtime_platform_windows_##CL##_##FN
 
 typedef enum {
-    SYSDLL_KERNEL32     = 0,    // kernel32 From WinBase.h
-    SYSDLL_NTDLL        = 1,    // ntdll    From our real kernel
-    SYSDLL_USER32       = 2,    // user32   From WinUser.h
-    SYSDLL_IPHLPAPI     = 3,    // iphlpapi From Iphlpapi.h
-    SYSDLL_WINSOCKAPI   = 4,    // mswsock  From WinSock.h
-    SYSDLL_WINSOCK2API  = 5,    // ws2_32   From WinSock2.h
-    SYSDLL_JVM          = 6,    // jvm      From our own jvm.dll
-    SYSDLL_defined      = 6     // must define as last idx_ + 1
+    SYSDLL_KERNEL32     = 0,    /* kernel32 From WinBase.h              */
+    SYSDLL_NTDLL        = 1,    /* ntdll    From our real kernel        */
+    SYSDLL_USER32       = 2,    /* user32   From WinUser.h              */
+    SYSDLL_IPHLPAPI     = 3,    /* iphlpapi From Iphlpapi.h             */
+    SYSDLL_WINSOCKAPI   = 4,    /* mswsock  From WinSock.h              */
+    SYSDLL_WINSOCK2API  = 5,    /* ws2_32   From WinSock2.h             */
+    SYSDLL_SHELL32      = 6,    /* shell32  From ShellAPI.h             */
+    SYSDLL_ADVAPI32     = 7,    /* advapi32 From WinBase.h              */
+    SYSDLL_JVM          = 8,    /* jvm      From our own jvm.dll        */
+
+    SYSDLL_defined      = 9     /* must define as last idx_ + 1         */
 } acr_dlltoken_e;
 
 /* Copied from http://source.winehq.org/source/include/winternl.h */